Package: loon
Type: Package
Title: Interactive Statistical Data Visualization
Version: 1.4.3
Date: 2025-06-18
Authors@R: c(person(given = "Adrian", family = "Waddell", 
                    email = "adrian@waddell.ch", 
                    role = c("aut")),
             person(given = "R. Wayne", family = "Oldford",
                    email = "rwoldford@uwaterloo.ca", 
                    role = c("aut", "cre", "ths")),
             person(given = "Zehao", family = "Xu", 
                    email = "z267xu@uwaterloo.ca", 
                    role = "ctb"),
             person(given = "Martin", family = "Gauch", 
                    email = "martin.gauch@student.kit.edu", 
                    role = "ctb")
             )
URL: https://great-northern-diver.github.io/loon/
Description: An extendable toolkit for interactive data visualization and exploration.
License: GPL-2
Depends: R (>= 3.5.0), methods, tcltk
Imports: tools, graphics, grDevices, utils, stats, gridExtra
Suggests: maps, sp, graph, scagnostics, PairViz, RColorBrewer,
        loon.data, rworldmap, mgcv, rgl, Rgraphviz, RDRToolbox,
        kernlab, scales, MASS, testthat, knitr, rmarkdown, png,
        formatR, covr
BugReports: https://github.com/great-northern-diver/loon/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-06-19 16:50:43 UTC; rwoldford
Author: Adrian Waddell [aut],
  R. Wayne Oldford [aut, cre, ths],
  Zehao Xu [ctb],
  Martin Gauch [ctb]
Maintainer: R. Wayne Oldford <rwoldford@uwaterloo.ca>
Repository: CRAN
Date/Publication: 2025-06-19 18:30:08 UTC
Built: R 4.6.0; ; 2026-04-28 02:22:50 UTC; unix
