# Generated by roxygen2: do not edit by hand

S3method("[",l_compound)
S3method("[",l_savedStates)
S3method("[",loon)
S3method("[<-",l_compound)
S3method("[<-",l_savedStates)
S3method("[<-",loon)
S3method(complement,loongraph)
S3method(get_facets,l_serialaxes)
S3method(get_facets,loon)
S3method(l_cget,character)
S3method(l_cget,l_compound)
S3method(l_cget,loon)
S3method(l_configure,character)
S3method(l_configure,l_compound)
S3method(l_configure,loon)
S3method(l_copyStates,l_compound)
S3method(l_copyStates,l_savedStates)
S3method(l_copyStates,loon)
S3method(l_createCompoundGrob,default)
S3method(l_createCompoundGrob,l_compound)
S3method(l_createCompoundGrob,l_pairs)
S3method(l_facet,l_serialaxes)
S3method(l_facet,loon)
S3method(l_getDeprecatedLinkedVar,default)
S3method(l_getDeprecatedLinkedVar,list)
S3method(l_getLocations,default)
S3method(l_getLocations,l_compound)
S3method(l_getLocations,l_facet)
S3method(l_getLocations,l_pairs)
S3method(l_getLocations,l_ts)
S3method(l_getLocations,loon)
S3method(l_getPlots,default)
S3method(l_getPlots,l_compound)
S3method(l_getPlots,l_facet)
S3method(l_getPlots,l_navgraph)
S3method(l_getPlots,l_ng_plots)
S3method(l_getPlots,l_pairs)
S3method(l_getPlots,l_ts)
S3method(l_getPlots,loon)
S3method(l_get_arrangeGrobArgs,default)
S3method(l_get_arrangeGrobArgs,l_compound)
S3method(l_get_arrangeGrobArgs,l_facet_grid)
S3method(l_get_arrangeGrobArgs,l_facet_wrap)
S3method(l_get_arrangeGrobArgs,l_pairs)
S3method(l_glyph_add,default)
S3method(l_graph,default)
S3method(l_graph,graph)
S3method(l_graph,loongraph)
S3method(l_graphswitch_add,default)
S3method(l_graphswitch_add,graph)
S3method(l_graphswitch_add,loongraph)
S3method(l_hist,array)
S3method(l_hist,character)
S3method(l_hist,data.frame)
S3method(l_hist,default)
S3method(l_hist,factor)
S3method(l_hist,list)
S3method(l_hist,matrix)
S3method(l_hist,table)
S3method(l_info_states,l_compound)
S3method(l_info_states,loon)
S3method(l_layer,Line)
S3method(l_layer,Lines)
S3method(l_layer,Polygon)
S3method(l_layer,Polygons)
S3method(l_layer,SpatialLines)
S3method(l_layer,SpatialLinesDataFrame)
S3method(l_layer,SpatialPoints)
S3method(l_layer,SpatialPointsDataFrame)
S3method(l_layer,SpatialPolygons)
S3method(l_layer,SpatialPolygonsDataFrame)
S3method(l_layer,density)
S3method(l_layer,map)
S3method(l_layer_smooth,default)
S3method(l_layer_smooth,l_compound)
S3method(l_layer_smooth,l_graph)
S3method(l_layer_smooth,l_plot)
S3method(l_nDimStateNames,character)
S3method(l_nDimStateNames,loon)
S3method(l_ng_plots,default)
S3method(l_ng_plots,measures)
S3method(l_ng_plots,scagnostics)
S3method(l_ng_ranges,default)
S3method(l_ng_ranges,measures)
S3method(l_ng_ranges,scagnostics)
S3method(l_plot,decomposed.ts)
S3method(l_plot,default)
S3method(l_plot,density)
S3method(l_plot,map)
S3method(l_plot,stl)
S3method(l_plot3D,default)
S3method(l_predict,default)
S3method(l_predict,glm)
S3method(l_predict,lm)
S3method(l_predict,loess)
S3method(l_predict,nls)
S3method(l_scaleto_active,default)
S3method(l_scaleto_active,l_compound)
S3method(l_scaleto_active,l_graph)
S3method(l_scaleto_active,l_hist)
S3method(l_scaleto_active,l_plot)
S3method(l_scaleto_plot,default)
S3method(l_scaleto_plot,l_compound)
S3method(l_scaleto_plot,l_graph)
S3method(l_scaleto_plot,l_hist)
S3method(l_scaleto_plot,l_plot)
S3method(l_scaleto_selected,default)
S3method(l_scaleto_selected,l_compound)
S3method(l_scaleto_selected,l_graph)
S3method(l_scaleto_selected,l_hist)
S3method(l_scaleto_selected,l_plot)
S3method(l_scaleto_world,default)
S3method(l_scaleto_world,l_compound)
S3method(l_scaleto_world,l_graph)
S3method(l_scaleto_world,l_hist)
S3method(l_scaleto_world,l_plot)
S3method(l_serialaxes,default)
S3method(linegraph,loongraph)
S3method(loonFacets,default)
S3method(loonFacets,l_serialaxes)
S3method(loonGlyphGrob,default)
S3method(loonGlyphGrob,image)
S3method(loonGlyphGrob,pointrange)
S3method(loonGlyphGrob,polygon)
S3method(loonGlyphGrob,primitive_glyph)
S3method(loonGlyphGrob,serialaxes)
S3method(loonGlyphGrob,text)
S3method(loonGrob,default)
S3method(loonGrob,l_compound)
S3method(loonGrob,l_graph)
S3method(loonGrob,l_hist)
S3method(loonGrob,l_layer_graph)
S3method(loonGrob,l_layer_group)
S3method(loonGrob,l_layer_histogram)
S3method(loonGrob,l_layer_line)
S3method(loonGrob,l_layer_lines)
S3method(loonGrob,l_layer_oval)
S3method(loonGrob,l_layer_points)
S3method(loonGrob,l_layer_polygon)
S3method(loonGrob,l_layer_polygons)
S3method(loonGrob,l_layer_rectangle)
S3method(loonGrob,l_layer_rectangles)
S3method(loonGrob,l_layer_scatterplot)
S3method(loonGrob,l_layer_text)
S3method(loonGrob,l_layer_texts)
S3method(loonGrob,l_navgraph)
S3method(loonGrob,l_navigator)
S3method(loonGrob,l_plot)
S3method(loonGrob,l_plot3D)
S3method(loonGrob,l_serialaxes)
S3method(loonGrob,l_ts)
S3method(loonGrob_layoutType,default)
S3method(loonGrob_layoutType,l_compound)
S3method(loonGrob_layoutType,l_facet)
S3method(loonGrob_layoutType,l_facet_grid)
S3method(loonGrob_layoutType,l_facet_wrap)
S3method(loonGrob_layoutType,l_pairs)
S3method(names,l_compound)
S3method(names,loon)
S3method(plot,loon)
S3method(plot,loongraph)
S3method(print,l_layer)
S3method(print,measures1d)
S3method(print,measures2d)
S3method(spAsList,Line)
S3method(spAsList,Lines)
S3method(spAsList,Polygon)
S3method(spAsList,Polygons)
S3method(spAsList,SpatialLines)
S3method(spAsList,SpatialLinesDataFrame)
S3method(spAsList,SpatialPolygons)
S3method(spAsList,SpatialPolygonsDataFrame)
S3method(spAsList,default)
export("l_aspect<-")
export("l_size<-")
export(L2_distance)
export(as.graph)
export(as.loongraph)
export(as_grid_size)
export(as_hex6color)
export(char2num.data.frame)
export(color_loon)
export(complement)
export(completegraph)
export(condGrob)
export(get_display_color)
export(get_facets)
export(get_font_info_from_tk)
export(get_layer_states)
export(get_model_display_order)
export(glyph_to_pch)
export(graphreduce)
export(grid.loon)
export(hex12tohex6)
export(l_Rlist2nestedTclList)
export(l_after_idle)
export(l_aspect)
export(l_basePaths)
export(l_binCut)
export(l_bind_canvas)
export(l_bind_canvas_delete)
export(l_bind_canvas_get)
export(l_bind_canvas_ids)
export(l_bind_canvas_reorder)
export(l_bind_context)
export(l_bind_context_delete)
export(l_bind_context_get)
export(l_bind_context_ids)
export(l_bind_context_reorder)
export(l_bind_glyph)
export(l_bind_glyph_delete)
export(l_bind_glyph_get)
export(l_bind_glyph_ids)
export(l_bind_glyph_reorder)
export(l_bind_item)
export(l_bind_item_delete)
export(l_bind_item_get)
export(l_bind_item_ids)
export(l_bind_item_reorder)
export(l_bind_layer)
export(l_bind_layer_delete)
export(l_bind_layer_get)
export(l_bind_layer_ids)
export(l_bind_layer_reorder)
export(l_bind_navigator)
export(l_bind_navigator_delete)
export(l_bind_navigator_get)
export(l_bind_navigator_ids)
export(l_bind_navigator_reorder)
export(l_bind_state)
export(l_bind_state_delete)
export(l_bind_state_get)
export(l_bind_state_ids)
export(l_bind_state_reorder)
export(l_breaks)
export(l_cget)
export(l_colRemoveAlpha)
export(l_colorName)
export(l_compoundPaths)
export(l_configure)
export(l_context_add_context2d)
export(l_context_add_geodesic2d)
export(l_context_add_slicing2d)
export(l_context_delete)
export(l_context_getLabel)
export(l_context_ids)
export(l_context_relabel)
export(l_copyStates)
export(l_createCompoundGrob)
export(l_create_handle)
export(l_currentindex)
export(l_currenttags)
export(l_data)
export(l_export)
export(l_export_valid_formats)
export(l_facet)
export(l_getBinData)
export(l_getBinIds)
export(l_getColorList)
export(l_getDeprecatedLinkedVar)
export(l_getFromPath)
export(l_getGraph)
export(l_getLinkedStates)
export(l_getLocations)
export(l_getOption)
export(l_getOptionNames)
export(l_getPlots)
export(l_getSavedStates)
export(l_getScaledData)
export(l_get_arrangeGrobArgs)
export(l_glyph_add)
export(l_glyph_add_image)
export(l_glyph_add_pointrange)
export(l_glyph_add_polygon)
export(l_glyph_add_serialaxes)
export(l_glyph_add_text)
export(l_glyph_delete)
export(l_glyph_getLabel)
export(l_glyph_getType)
export(l_glyph_ids)
export(l_glyph_relabel)
export(l_glyphs_inspector)
export(l_glyphs_inspector_image)
export(l_glyphs_inspector_pointrange)
export(l_glyphs_inspector_serialaxes)
export(l_glyphs_inspector_text)
export(l_graph)
export(l_graph_inspector)
export(l_graph_inspector_analysis)
export(l_graph_inspector_navigators)
export(l_graphswitch)
export(l_graphswitch_add)
export(l_graphswitch_delete)
export(l_graphswitch_get)
export(l_graphswitch_getLabel)
export(l_graphswitch_ids)
export(l_graphswitch_move)
export(l_graphswitch_relabel)
export(l_graphswitch_reorder)
export(l_graphswitch_set)
export(l_help)
export(l_hexcolor)
export(l_hist)
export(l_hist_inspector)
export(l_hist_inspector_analysis)
export(l_image_import_array)
export(l_image_import_files)
export(l_imageviewer)
export(l_info_states)
export(l_instantiateGrob)
export(l_isLoonWidget)
export(l_layer)
export(l_layer.density)
export(l_layer.map)
export(l_layer_bbox)
export(l_layer_contourLines)
export(l_layer_delete)
export(l_layer_demote)
export(l_layer_expunge)
export(l_layer_getChildren)
export(l_layer_getLabel)
export(l_layer_getParent)
export(l_layer_getType)
export(l_layer_group)
export(l_layer_groupVisibility)
export(l_layer_heatImage)
export(l_layer_hide)
export(l_layer_ids)
export(l_layer_index)
export(l_layer_isVisible)
export(l_layer_layerVisibility)
export(l_layer_line)
export(l_layer_lines)
export(l_layer_lower)
export(l_layer_move)
export(l_layer_oval)
export(l_layer_points)
export(l_layer_polygon)
export(l_layer_polygons)
export(l_layer_printTree)
export(l_layer_promote)
export(l_layer_raise)
export(l_layer_rasterImage)
export(l_layer_rectangle)
export(l_layer_rectangles)
export(l_layer_relabel)
export(l_layer_show)
export(l_layer_smooth)
export(l_layer_text)
export(l_layer_texts)
export(l_layers_inspector)
export(l_loonWidgets)
export(l_loon_inspector)
export(l_make_glyphs)
export(l_move_grid)
export(l_move_halign)
export(l_move_hdist)
export(l_move_jitter)
export(l_move_reset)
export(l_move_valign)
export(l_move_vdist)
export(l_nDimStateNames)
export(l_navgraph)
export(l_navigator_add)
export(l_navigator_delete)
export(l_navigator_getLabel)
export(l_navigator_getPath)
export(l_navigator_ids)
export(l_navigator_relabel)
export(l_navigator_walk_backward)
export(l_navigator_walk_forward)
export(l_navigator_walk_path)
export(l_nestedTclList2Rlist)
export(l_ng_plots)
export(l_ng_ranges)
export(l_pairs)
export(l_plot)
export(l_plot3D)
export(l_plot_inspector)
export(l_plot_inspector_analysis)
export(l_predict)
export(l_primitiveGlyphs)
export(l_redraw)
export(l_resize)
export(l_saveStates)
export(l_scale3D)
export(l_scaleto_active)
export(l_scaleto_layer)
export(l_scaleto_plot)
export(l_scaleto_selected)
export(l_scaleto_world)
export(l_serialaxes)
export(l_serialaxes_inspector)
export(l_setAspect)
export(l_setColorList)
export(l_setColorList_ColorBrewer)
export(l_setColorList_baseR)
export(l_setColorList_ggplot2)
export(l_setColorList_hcl)
export(l_setColorList_loon)
export(l_setGrobPlotView)
export(l_setLinkedStates)
export(l_setOption)
export(l_size)
export(l_state_names)
export(l_subwin)
export(l_throwErrorIfNotLoonWidget)
export(l_toR)
export(l_toplevel)
export(l_updateGrob)
export(l_userOptionDefault)
export(l_userOptions)
export(l_web)
export(l_worldview)
export(l_zoom)
export(linegraph)
export(loonFacets)
export(loonGlyphGrob)
export(loonGrob)
export(loonGrob_layoutType)
export(loon_palette)
export(loongraph)
export(measures1d)
export(measures2d)
export(ndtransitiongraph)
export(scagnostics2d)
export(spAsList)
export(spunlist)
export(tcl_img_2_r_raster)
export(tkcolors)
import(grDevices)
import(grid)
import(methods)
import(stats)
import(tcltk)
importFrom(grDevices,xy.coords)
importFrom(utils,browseURL)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
